@@ -89,8 +89,9 @@ if ($sched->{'reseller'}) {
 # Work out who the schedule is being run for
 if ($sched->{'plugged'} &&
     &plugin_defined($sched->{'plugged'}, 'feature_can_domain')) {
-	# Plugin can enforce a domain if the domain is allowed when the user is a
-	# master admin or when passes ACL access check otherwise (owner/reseller)
+	# Plugin can enforce a domain if the domain is allowed when the user
+	# is a master admin or when passes ACL access check otherwise
+	# (owner/reseller)
 	my ($plugin_d, $plugin_cbmode) = &plugin_call($sched->{'plugged'},
 		'feature_can_domain', $sched);
 	$cbmode = $plugin_cbmode;
@@ -232,8 +233,8 @@ foreach $dest (@strfdests) {
 			  $size, $ok,  $mode, $output, $errdoms,
 			  $asd ? $asd->{'user'} : undef, $key, $sched->{'id'},
 			  $sched->{'fmt'}, $sched->{'ownrestore'},
-			  $sched->{'compression'}, $sched->{'desc'},
-			  $sched);
+			  $sched->{'compression'}, $sched->{'nosign'},
+			  $sched->{'desc'}, $sched);
 	}
 
 PREFAILED:
@@ -245,7 +246,7 @@ if ($sched->{'email'} && $has_mailboxes &&
 	$output_header = "";
 	# Nice format $dest for email
 	$dest = &nice_backup_url($strfdests[0]);
-	if ($ok && !@$errdoms) {
+	if ($ok && !@$errdoms && $size) {
 		if (@perrs) {
 			# Worked, but purging failed
 			$output_header .= &text('backup_donepurge',
@@ -259,7 +260,7 @@ if ($sched->{'email'} && $has_mailboxes &&
 			$subject = &text('backup_donesubject', $host, $dest);
 			}
 		}
-	elsif ($ok && @$errdoms) {
+	elsif ($ok && @$errdoms && $size) {
 		# Worked for some domains but not all
 		$output_header .= &text('backup_partial',
 					&nice_size($size))." ";
