@@ -244,10 +244,11 @@ else {
 
 if ($in->{'postgres'}) {
 	# Enable and start PostgreSQL
-	&require_postgres();
 	if (!&foreign_installed("postgresql", 0)) {
-		return $text{'wizard_epostgresinst'};
+		return &text('wizard_epostgresinst', $virtualmin_docs_link.
+			"installation/automated/#postgresql");
 		}
+	&require_postgres();
 	$config{'postgres'} ||= 1;
 	if (&postgresql::is_postgresql_running() == 0) {
 		local $err = &postgresql::start_postgresql();
@@ -300,7 +301,10 @@ else {
 					$text{'wizard_mysql_pass0'}));
 		}
 	else {
-		if (defined(&mysql::mysql_login_type) &&
+		# Do we have socket authentication plugin?
+		my $plugins = &mysql::list_authentication_plugins();
+		my $has_unix_socket = grep { $_ eq 'unix_socket' } @$plugins;
+		if ($has_unix_socket && defined(&mysql::mysql_login_type) &&
 		    &mysql::mysql_login_type($mysql::mysql_login || 'root')) {
 			# Using socket authentication
 			my $text_mysql_def = $text{'wizard_mysql_pass2'} .
@@ -340,12 +344,18 @@ sub wizard_parse_mysql
 {
 local ($in) = @_;
 &require_mysql();
+local $user = $mysql::mysql_login || 'root';
 if ($in->{'socket'} && !$in->{'mypass'}) {
-	# No password needed
+	# Socket auth with no password. Check if we actually have socket plugin,
+	# and not just empty password
+	my $mode = &mysql::mysql_login_type($user);
+	if ($mode ne 'socket') {
+		&mysql::change_user_password('', $user, 'localhost',
+					     'unix_socket');
+		}
 	return undef;
 	}
 local $pass = $in->{'mypass_def'} ? $mysql::mysql_pass : $in->{'mypass'};
-local $user = $mysql::mysql_login || 'root';
 if ($in->{'needchange'}) {
 	# Change the password used by subsequent code to validate that it works
 	$mysql::mysql_pass = $pass;
@@ -473,7 +483,9 @@ $tmpl->{'dns_ns'} = join(" ", @secns);
 
 # Save skip option
 $config{'prins_skip'} = $in{'prins_skip'};
+&lock_file($module_config_file);
 &save_module_config();
+&unlock_file($module_config_file);
 }
 
 sub wizard_show_email
@@ -481,23 +493,43 @@ sub wizard_show_email
 &foreign_require("mailboxes");
 print &ui_table_row(undef, $text{'wizard_email_desc'}, 2);
 
+# From address for email notifications
 print &ui_table_row($text{'wizard_from_addr'},
 	&ui_opt_textbox("from_addr", $config{'from_addr'}, 50,
 		$text{'default'}." (".&mailboxes::get_from_address().")<br>",
 		$text{'wizard_from_addr2'}));
+
+# Default to address for notifications
+print &ui_table_row($text{'wizard_to_addr'},
+	&ui_opt_textbox("to_addr", $gconfig{'webmin_email_to'}, 50,
+			$text{'wizard_to_addr_none'}));
 }
 
 sub wizard_parse_email
 {
 local ($in) = @_;
+
+&lock_file($module_config_file);
 if ($in->{'from_addr_def'}) {
 	delete($config{'from_addr'});
 	}
 else {
 	$in->{'from_addr'} =~ /\S+\@\S+/ || return $text{'wizard_efrom_addr'};
 	$config{'from_addr'} = $in->{'from_addr'};
-	&save_module_config();
 	}
+&save_module_config();
+&unlock_file($module_config_file);
+
+&lock_file("$config_directory/config");
+if ($in->{'to_addr_def'}) {
+	delete($gconfig{'webmin_email_to'});
+	}
+else {
+	$in->{'to_addr'} =~ /\S+\@\S+/ || return $text{'wizard_efrom_addr'};
+	$gconfig{'webmin_email_to'} = $in->{'to_addr'};
+	}
+&write_file("$config_directory/config", \%gconfig);
+&unlock_file("$config_directory/config");
 }
 
 sub wizard_show_done
